@@ -42,9 +42,9 @@ callBackend <- function(..., PACKAGE) {
 
 ## check the number of predictors to sequence for robust and groupwise LARS
 ## sequence predictors as long as there are twice as many observations
-checkSMax <- function(sMax, n, p, robust = TRUE) {
+checkSMax <- function(sMax, n, p) {
   sMax <- rep(as.integer(sMax), length.out=1)
-  bound <- min(p, if(robust) floor(n/2) else n-1)
+  bound <- min(p, if(is.na(sMax)) floor(n/2) else n-1)
   if(!isTRUE(is.finite(sMax)) || sMax > bound) sMax <- bound
   sMax
 }
@@ -53,22 +53,25 @@ checkSMax <- function(sMax, n, p, robust = TRUE) {
 checkSRange <- function(s, sMax = NA) {
   s <- as.integer(s)
   if(length(s) == 0) s <- c(0, sMax)
-  else if(length(s) == 1) {
-    s <- if(isTRUE(is.finite(s))) rep.int(s, 2) else c(0, sMax)
-  } else {
-    s <- s[1:2]
-    if(!isTRUE(is.finite(s[1]))) s[1] <- 0
-    if(!isTRUE(is.finite(s[2]))) s[2] <- sMax
-  }
+  else if(length(s) == 1) s <- rep.int(s, 2)
+  else s <- s[1:2]
+  if(!isTRUE(is.finite(s[1]))) s[1] <- 0
+  if(isTRUE(is.finite(s[2]))) {
+    if(s[1] > s[2]) s[1] <- s[2]
+  } else s[2] <- NA
   s
 }
 
 ## check steps for coef(), fitted(), residuals(), predict(), ... methods
-checkSteps <- function(s, sMin, sMax) {
-  if(!is.numeric(s) || length(s) == 0 || any(!is.finite(s)) || 
-       any(s < sMin) || any(s > sMax)) {
-    stop(sprintf("invalid step, must be between %d and %d", sMin, sMax))
+checkSteps <- function(s, sMin, sMax, recycle = FALSE, ...) {
+  ok <- is.numeric(s) && length(s) > 0 && all(is.finite(s))
+  if(ok) {
+    if(isTRUE(recycle)) {
+      s[s < sMin] <- sMin
+      s[s > sMax] <- sMax
+    } else ok <- all(s >= sMin) && all(s <= sMax)
   }
+  if(!ok) stop(sprintf("invalid step, must be between %d and %d", sMin, sMax))
   s
 }
 
