@@ -1,6 +1,6 @@
 # -------------------------------------------------------------------
 # Author: Andreas Alfons
-#         KU Leuven
+#         Erasmus University Rotterdam
 #
 # based on code by Jafar A. Khan, Stefan Van Aelst and Ruben H. Zamar
 # -------------------------------------------------------------------
@@ -93,28 +93,29 @@ winsorize <- function(x, ...) UseMethod("winsorize")
 #' @export
 
 winsorize.default <- function(x, standardized = FALSE, centerFun = median, 
-        scaleFun = mad, const = 2, return = c("data", "weights"), ...) {
-    ## initializations
-    standardized <- isTRUE(standardized)
-    if(standardized) return <- match.arg(return)
-    else {
-        # standardize data
-        x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
-        center <- attr(x, "center")
-        scale <- attr(x, "scale")
-    }
-    ## winsorize standardized data
-#    ind <- abs(x) > const           # observations in 'x' that need to be shrunken
-#    x[ind] <- const * sign(x[ind])  # winsorize
-    weights <- pmin(const / abs(x), 1)
-    if(standardized && return == "weights") return(weights)
-    x <- weights * x
-    ## finalizations
-    if(!standardized) {
-        # transform back to original scale and remove attributes
-        x <- c(x * scale + center)
-    }
-    x
+                              scaleFun = mad, const = 2, 
+                              return = c("data", "weights"), ...) {
+  ## initializations
+  standardized <- isTRUE(standardized)
+  if(standardized) return <- match.arg(return)
+  else {
+    # standardize data
+    x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
+    center <- attr(x, "center")
+    scale <- attr(x, "scale")
+  }
+  ## winsorize standardized data
+#   ind <- abs(x) > const           # observations in 'x' that need to be shrunken
+#   x[ind] <- const * sign(x[ind])  # winsorize
+  weights <- pmin(const / abs(x), 1)
+  if(standardized && return == "weights") return(weights)
+  x <- weights * x
+  ## finalizations
+  if(!standardized) {
+    # transform back to original scale and remove attributes
+    x <- c(x * scale + center)
+  }
+  x
 }
 
 
@@ -123,61 +124,62 @@ winsorize.default <- function(x, standardized = FALSE, centerFun = median,
 #' @export
 
 winsorize.matrix <- function(x, standardized = FALSE, centerFun = median, 
-        scaleFun = mad, const = 2, prob = 0.95, tol = .Machine$double.eps^0.5, 
-        return = c("data", "weights"), ...) {
-    ## initializations
-    m <- ncol(x)
-    standardized <- isTRUE(standardized)
-    if(standardized) return <- match.arg(return)
-    ## winsorize the data
-    if(m == 1) {
-        attributes <- attributes(x)
-        x <- winsorize(c(x), standardized=standardized, centerFun=centerFun, 
-            scaleFun=scaleFun, const=const, return=return, ...)
-        if(!(standardized && return == "weights")) attributes(x) <- attributes
-    } else {
-        if(nrow(x) <= m) {
-            stop("not enough observations for inversion of correlation matrix")
-        }
-        if(!standardized) {
-            # standardize data
-            attributes <- attributes(x)
-            x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
-            center <- attr(x, "center")
-            scale <- attr(x, "scale")
-        }
-        ## compute correlation matrix (call C++ function)
-        R <- .Call("R_corMatHuber", R_x=x, R_c=const, R_prob=prob, R_tol=tol, 
-            PACKAGE="robustHD")
-        # check if correlation matrix is positive definite and perform 
-        # corrections if necessary
-        eig <- eigen(R, symmetric=TRUE)
-        if(eig$values[m] < 0) {  # last eigenvalue is the smallest
-            Q <- eig$vectors  # matrix of eigenvectors
-            lambda <- apply(x %*% Q, 2, scaleFun)^2
-            R <- Q %*% diag(lambda) %*% t(Q)
-        }
-        ## compute Mahalanobis distances
-        # function 'mahalanobis()' requires suppling estimates for the centers, 
-        # hence it is not used here
-        invR <- solve(R)
-        md <- rowSums((x %*% invR) * x)  # squared Mahalanobis distance
-        ## shrink observations with too large distances
-        d <- qchisq(prob, df=m)  # quantile of the chi-squared distribution
-#        ind <- which(md > d)  # select observations that need to be shrunken
-#        x[ind,] <- x[ind,] * sqrt(d / md[ind])  # shrink selected observations
-        weights <- pmin(sqrt(d / md), 1)
-        if(standardized && return == "weights") return(weights)
-        x <- weights * x
-        ## finalizations
-        if(!standardized) {
-            # transform back to original scale and remove attributes
-            x <- sweep(x, 2, scale, "*", check.margin=FALSE)
-            x <- sweep(x, 2, center, "+", check.margin=FALSE)
-            attributes(x) <- attributes
-        }
+                             scaleFun = mad, const = 2, prob = 0.95, 
+                             tol = .Machine$double.eps^0.5, 
+                             return = c("data", "weights"), ...) {
+  ## initializations
+  m <- ncol(x)
+  standardized <- isTRUE(standardized)
+  if(standardized) return <- match.arg(return)
+  ## winsorize the data
+  if(m == 1) {
+    attributes <- attributes(x)
+    x <- winsorize(c(x), standardized=standardized, centerFun=centerFun, 
+                   scaleFun=scaleFun, const=const, return=return, ...)
+    if(!(standardized && return == "weights")) attributes(x) <- attributes
+  } else {
+    if(nrow(x) <= m) {
+      stop("not enough observations for inversion of correlation matrix")
     }
-    x
+    if(!standardized) {
+      # standardize data
+      attributes <- attributes(x)
+      x <- robStandardize(x, centerFun=centerFun, scaleFun=scaleFun, ...)
+      center <- attr(x, "center")
+      scale <- attr(x, "scale")
+    }
+    ## compute correlation matrix (call C++ function)
+    R <- .Call("R_corMatHuber", R_x=x, R_c=const, R_prob=prob, R_tol=tol, 
+               PACKAGE="robustHD")
+    # check if correlation matrix is positive definite and perform 
+    # corrections if necessary
+    eig <- eigen(R, symmetric=TRUE)
+    if(eig$values[m] < 0) {  # last eigenvalue is the smallest
+      Q <- eig$vectors  # matrix of eigenvectors
+      lambda <- apply(x %*% Q, 2, scaleFun)^2
+      R <- Q %*% diag(lambda) %*% t(Q)
+    }
+    ## compute Mahalanobis distances
+    # function 'mahalanobis()' requires suppling estimates for the centers, 
+    # hence it is not used here
+    invR <- solve(R)
+    md <- rowSums((x %*% invR) * x)  # squared Mahalanobis distance
+    ## shrink observations with too large distances
+    d <- qchisq(prob, df=m)  # quantile of the chi-squared distribution
+    #        ind <- which(md > d)  # select observations that need to be shrunken
+    #        x[ind,] <- x[ind,] * sqrt(d / md[ind])  # shrink selected observations
+    weights <- pmin(sqrt(d / md), 1)
+    if(standardized && return == "weights") return(weights)
+    x <- weights * x
+    ## finalizations
+    if(!standardized) {
+      # transform back to original scale and remove attributes
+      x <- sweep(x, 2, scale, "*", check.margin=FALSE)
+      x <- sweep(x, 2, center, "+", check.margin=FALSE)
+      attributes(x) <- attributes
+    }
+  }
+  x
 }
 
 
