@@ -1,6 +1,6 @@
 /*
  * Author: Andreas Alfons
- *         KU Leuven
+ *         Erasmus University Rotterdam
  */
 
 #ifndef _robustHD_FASTSPARSELTS_H
@@ -21,8 +21,8 @@ RcppExport SEXP R_testLasso(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_subset,
 RcppExport SEXP R_testCStep(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_lassoSubset,
 		SEXP R_intercept, SEXP R_tol, SEXP R_eps, SEXP R_useGram);
 RcppExport SEXP R_testKeepBest(SEXP R_subsetMat, SEXP R_crits, SEXP R_nkeep);
-RcppExport SEXP R_fastSparseLTS(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_subsets,
-		SEXP R_intercept, SEXP R_ncstep, SEXP R_nkeep, SEXP R_tol, SEXP R_eps,
+RcppExport SEXP R_fastSparseLTS(SEXP R_x, SEXP R_y, SEXP R_lambda, SEXP R_initial,
+  	SEXP R_intercept, SEXP R_ncstep, SEXP R_nkeep, SEXP R_tol, SEXP R_eps,
 		SEXP R_useGram, SEXP R_ncores);
 
 #endif
